<?php
defined( 'ABSPATH' ) or die( 'No script kiddies please!' );

// Admin menu
function cacsp_menu() {
	add_options_page( __( 'Cookies and Content Security Policy', 'cookies-and-content-security-policy' ), __( 'Cookies and Content Security Policy', 'cookies-and-content-security-policy' ), 'manage_options', 'cacsp_settings', 'cacsp_options' );
}

// Settings textarea table row
function cacsp_settings_textarea_row( $header, $id, $value, $code = true, $example = '', $placeholder = '' ) {
	if ( $code ) {
		$code = ' code';
	}
	$cacsp_settings_textarea_row = '<tr valign="top">
		<th scope="row">' . $header . '</th>
		<td>
			<textarea name="' . $id . '" id="' . $id . '" rows="10" cols="50" class="large-text' . $code . '" placeholder="' . esc_attr( $placeholder ) . '">' . $value . '</textarea>';
			if ( $example ) {
				$cacsp_settings_textarea_row .= '<small>' . __( 'Example:', 'cookies-and-content-security-policy' ) . '<br>' . $example . '</small>';
			}
		$cacsp_settings_textarea_row .= '</td> 
	</tr>';
	return $cacsp_settings_textarea_row;
}

// Settings input table row
function cacsp_settings_input_row( $header, $id, $value, $code = true, $example = '', $placeholder = '' ) {
	if ( $code ) {
		$code = ' code';
	}
	$cacsp_settings_input_row = '<tr valign="top">
		<th scope="row">' . $header . '</th>
		<td>
			<input name="' . $id . '" type="text" id="' . $id . '" value="' . $value . '" class="large-text' . $code . '" placeholder="' . esc_attr( $placeholder ) . '">';
			if ( $example ) {
				$cacsp_settings_input_row .= '<small>' . __( 'Example:', 'cookies-and-content-security-policy' ) . '<br>' . $example . '</small>';
			}
			$cacsp_settings_input_row .= '
		</td> 
	</tr>';
	return $cacsp_settings_input_row;
}

// Admin page
add_action( 'admin_menu', 'cacsp_menu' );
function cacsp_options() {
	$can_change_all = false;
	$cacsp_nonce_set = false;
	$cacsp_nonce_name = '';
	if ( isset( $_POST['cacsp_nonce_name'] ) ) {
		$cacsp_nonce_set = isset( $_POST['cacsp_nonce_name'] );
		$cacsp_nonce_name = $_POST['cacsp_nonce_name'];
	}
	$cacsp_nonce_verify = wp_verify_nonce( $cacsp_nonce_name, 'cacsp_nonce_action' );
	$cacsp_option_forms = get_cacsp_options( 'cacsp_option_forms' );
	if ( current_user_can( 'manage_options' ) && $cacsp_nonce_set && $cacsp_nonce_verify ) {
		$can_change_all = true;
		update_option( 'cacsp_option_active', intval( 1 ) );
	}
	// Activate
	if ( isset( $_POST['save_cacsp_settings_activate'] ) && $can_change_all ) {
		update_option( 'cacsp_option_actived', sanitize_text_field( $_POST['cacsp_option_actived'] ) );
		echo '<div id="message" class="updated fade">
			<p>' . __( 'Your settings are now updated', 'cookies-and-content-security-policy' ) . '</p>
		</div>';
	}
	// Update domain options
	elseif ( isset( $_POST['save_cacsp_settings_domains'] ) && $can_change_all ) {
		// Always allowed
        update_option( 'cacsp_option_always_scripts', cacsp_sanitize_domains( $_POST['cacsp_option_always_scripts'] ) );
        update_option( 'cacsp_option_always_images', cacsp_sanitize_domains( $_POST['cacsp_option_always_images'] ) );
        update_option( 'cacsp_option_always_frames', cacsp_sanitize_domains( $_POST['cacsp_option_always_frames'] ) );
        if ( $cacsp_option_forms ) {
	        update_option( 'cacsp_option_always_forms', cacsp_sanitize_domains( $_POST['cacsp_option_always_forms'] ) );
	    }
		// Statistics
        update_option( 'cacsp_option_statistics_scripts', cacsp_sanitize_domains( $_POST['cacsp_option_statistics_scripts'] ) );
        update_option( 'cacsp_option_statistics_images', cacsp_sanitize_domains( $_POST['cacsp_option_statistics_images'] ) );
        update_option( 'cacsp_option_statistics_frames', cacsp_sanitize_domains( $_POST['cacsp_option_statistics_frames'] ) );
        if ( $cacsp_option_forms ) {
	        update_option( 'cacsp_option_statistics_forms', cacsp_sanitize_domains( $_POST['cacsp_option_statistics_forms'] ) );
	    }
        // Experience
        update_option( 'cacsp_option_experience_scripts', cacsp_sanitize_domains( $_POST['cacsp_option_experience_scripts'] ) );
        update_option( 'cacsp_option_experience_images', cacsp_sanitize_domains( $_POST['cacsp_option_experience_images'] ) );
        update_option( 'cacsp_option_experience_frames', cacsp_sanitize_domains( $_POST['cacsp_option_experience_frames'] ) );
        if ( $cacsp_option_forms ) {
	        update_option( 'cacsp_option_experience_forms', cacsp_sanitize_domains( $_POST['cacsp_option_experience_forms'] ) );
	    }
        // Marketing
        update_option( 'cacsp_option_markerting_scripts', cacsp_sanitize_domains( $_POST['cacsp_option_markerting_scripts'] ) );
        update_option( 'cacsp_option_markerting_images', cacsp_sanitize_domains( $_POST['cacsp_option_markerting_images'] ) );
        update_option( 'cacsp_option_markerting_frames', cacsp_sanitize_domains( $_POST['cacsp_option_markerting_frames'] ) );
        if ( $cacsp_option_forms ) {
	        update_option( 'cacsp_option_markerting_forms', cacsp_sanitize_domains( $_POST['cacsp_option_markerting_forms'] ) );
	    }

		echo '<div id="message" class="updated fade">
			<p>' . __( 'Your settings are now updated', 'cookies-and-content-security-policy' ) . '</p>
		</div>';
	} elseif ( isset( $_POST['save_cacsp_settings_texts'] ) && $can_change_all ) {
		update_option( 'cacsp_option_text_header', cacsp_sanitize_text_field_with_html( $_POST['cacsp_option_text_header'] ) );
		update_option( 'cacsp_option_text_info', cacsp_sanitize_text_field_with_html( $_POST['cacsp_option_text_info'] ) );
		update_option( 'cacsp_option_text_link_text', cacsp_sanitize_text_field_with_html( $_POST['cacsp_option_text_link_text'] ) );
		update_option( 'cacsp_option_text_settings', cacsp_sanitize_text_field_with_html( $_POST['cacsp_option_text_settings'] ) );
		update_option( 'cacsp_option_text_always_allow_header', cacsp_sanitize_text_field_with_html( $_POST['cacsp_option_text_always_allow_header'] ) );
		update_option( 'cacsp_option_text_always_allow_description', cacsp_sanitize_text_field_with_html( $_POST['cacsp_option_text_always_allow_description'] ) );
		update_option( 'cacsp_option_text_statistics_header', cacsp_sanitize_text_field_with_html( $_POST['cacsp_option_text_statistics_header'] ) );
		update_option( 'cacsp_option_text_statistics_description', cacsp_sanitize_text_field_with_html( $_POST['cacsp_option_text_statistics_description'] ) );
		update_option( 'cacsp_option_text_experience_header', cacsp_sanitize_text_field_with_html( $_POST['cacsp_option_text_experience_header'] ) );
		update_option( 'cacsp_option_text_experience_description', cacsp_sanitize_text_field_with_html( $_POST['cacsp_option_text_experience_description'] ) );
		update_option( 'cacsp_option_text_marketing_header', cacsp_sanitize_text_field_with_html( $_POST['cacsp_option_text_marketing_header'] ) );
		update_option( 'cacsp_option_text_marketing_description', cacsp_sanitize_text_field_with_html( $_POST['cacsp_option_text_marketing_description'] ) );
		update_option( 'cacsp_option_settings_button', cacsp_sanitize_text_field_with_html( $_POST['cacsp_option_settings_button'] ) );
		update_option( 'cacsp_option_accept_all_button', cacsp_sanitize_text_field_with_html( $_POST['cacsp_option_accept_all_button'] ) );
		update_option( 'cacsp_option_save_button', cacsp_sanitize_text_field_with_html( $_POST['cacsp_option_save_button'] ) );
		update_option( 'cacsp_review_settings_description', cacsp_sanitize_text_field_with_html( $_POST['cacsp_review_settings_description'] ) );
		update_option( 'cacsp_review_settings_button', cacsp_sanitize_text_field_with_html( $_POST['cacsp_review_settings_button'] ) );
		update_option( 'cacsp_not_allowed_description', cacsp_sanitize_text_field_with_html( $_POST['cacsp_not_allowed_description'] ) );
		update_option( 'cacsp_not_allowed_button', cacsp_sanitize_text_field_with_html( $_POST['cacsp_not_allowed_button'] ) );
		echo '<div id="message" class="updated fade">
			<p>' . __( 'Your settings are now updated', 'cookies-and-content-security-policy' ) . '</p>
		</div>';
	} elseif ( isset( $_POST['save_cacsp_settings_settings'] ) && $can_change_all ) {
		update_option( 'cacsp_option_only_csp', intval( isset( $_POST['cacsp_option_only_csp'] ) ) );
		update_option( 'cacsp_option_own_style', intval( isset( $_POST['cacsp_option_own_style'] ) ) );
		update_option( 'cacsp_option_own_js', intval( isset( $_POST['cacsp_option_own_js'] ) ) );
		update_option( 'cacsp_option_banner', intval( isset( $_POST['cacsp_option_banner'] ) ) );
		update_option( 'cacsp_option_allow_use_site', intval( isset( $_POST['cacsp_option_allow_use_site'] ) ) );
		update_option( 'cacsp_option_forms', intval( isset( $_POST['cacsp_option_forms'] ) ) );
		update_option( 'cacsp_option_meta', intval( isset( $_POST['cacsp_option_meta'] ) ) );
		update_option( 'cacsp_option_debug', intval( isset( $_POST['cacsp_option_debug'] ) ) );
		update_option( 'cacsp_option_settings_policy_link', intval( $_POST['cacsp_option_settings_policy_link'] ) );
		echo '<div id="message" class="updated fade">
			<p>' . __( 'Your settings are now updated', 'cookies-and-content-security-policy' ) . '</p>
		</div>';
	} elseif ( isset( $_POST['save_cacsp_settings_colors'] ) && $can_change_all ) {
		update_option( 'cacsp_option_color_backdrop', sanitize_hex_color( $_POST['cacsp_option_color_backdrop'] ) );
		update_option( 'cacsp_option_color_modal_bg', sanitize_hex_color( $_POST['cacsp_option_color_modal_bg'] ) );
		update_option( 'cacsp_option_color_modal_header_bg', sanitize_hex_color( $_POST['cacsp_option_color_modal_header_bg'] ) );
		update_option( 'cacsp_option_color_modal_list_border', sanitize_hex_color( $_POST['cacsp_option_color_modal_list_border'] ) );
		update_option( 'cacsp_option_color_modal_text_color', sanitize_hex_color( $_POST['cacsp_option_color_modal_text_color'] ) );
		update_option( 'cacsp_option_color_modal_header_text_color', sanitize_hex_color( $_POST['cacsp_option_color_modal_header_text_color'] ) );
		update_option( 'cacsp_option_color_text_on', sanitize_hex_color( $_POST['cacsp_option_color_text_on'] ) );
		update_option( 'cacsp_option_color_off', sanitize_hex_color( $_POST['cacsp_option_color_off'] ) );
		update_option( 'cacsp_option_color_on', sanitize_hex_color( $_POST['cacsp_option_color_on'] ) );
		update_option( 'cacsp_option_color_settings_button', sanitize_hex_color( $_POST['cacsp_option_color_settings_button'] ) );
		update_option( 'cacsp_option_color_settings_button_border', sanitize_hex_color( $_POST['cacsp_option_color_settings_button_border'] ) );
		update_option( 'cacsp_option_color_settings_button_text', sanitize_hex_color( $_POST['cacsp_option_color_settings_button_text'] ) );
		update_option( 'cacsp_option_color_save_button', sanitize_hex_color( $_POST['cacsp_option_color_save_button'] ) );
		update_option( 'cacsp_option_color_save_button_border', sanitize_hex_color( $_POST['cacsp_option_color_save_button_border'] ) );
		update_option( 'cacsp_option_color_save_button_text', sanitize_hex_color( $_POST['cacsp_option_color_save_button_text'] ) );
		update_option( 'cacsp_option_color_accept_button', sanitize_hex_color( $_POST['cacsp_option_color_accept_button'] ) );
		update_option( 'cacsp_option_color_accept_button_border', sanitize_hex_color( $_POST['cacsp_option_color_accept_button_border'] ) );
		update_option( 'cacsp_option_color_accept_button_text', sanitize_hex_color( $_POST['cacsp_option_color_accept_button_text'] ) );
		echo '<div id="message" class="updated fade">
			<p>' . __( 'Your settings are now updated', 'cookies-and-content-security-policy' ) . '</p>
		</div>';
	}
	?>

	<div class="wrap">
		<h1><?php _e( 'Cookies and Content Security Policy', 'cookies-and-content-security-policy' ); ?></h1>

		<form method="post">
			<?php
			$tab = '';
			if ( isset( $_GET[ 'tab' ] ) ) {
				$tab = sanitize_key( $_GET[ 'tab' ] );
			}
			$active_tab = strlen( $tab ) ? $tab : 'activate';
			?>

			<h2 class="nav-tab-wrapper">
				<a href="?page=cacsp_settings&tab=activate" class="nav-tab <?php echo $active_tab == 'activate' ? 'nav-tab-active' : ''; ?>"><?php _e( 'Activate', 'cookies-and-content-security-policy' ); ?></a>
				<a href="?page=cacsp_settings&tab=domains" class="nav-tab <?php echo $active_tab == 'domains' ? 'nav-tab-active' : ''; ?>"><?php _e( 'Domains', 'cookies-and-content-security-policy' ); ?></a>
				<a href="?page=cacsp_settings&tab=texts" class="nav-tab <?php echo $active_tab == 'texts' ? 'nav-tab-active' : ''; ?>"><?php _e( 'Texts', 'cookies-and-content-security-policy' ); ?></a>
				<a href="?page=cacsp_settings&tab=settings" class="nav-tab <?php echo $active_tab == 'settings' ? 'nav-tab-active' : ''; ?>"><?php _e( 'Settings', 'cookies-and-content-security-policy' ); ?></a>
				<a href="?page=cacsp_settings&tab=colors" class="nav-tab <?php echo $active_tab == 'colors' ? 'nav-tab-active' : ''; ?>"><?php _e( 'Colors', 'cookies-and-content-security-policy' ); ?></a>
				<a href="?page=cacsp_settings&tab=support" class="nav-tab <?php echo $active_tab == 'support' ? 'nav-tab-active' : ''; ?>"><?php _e( 'Support', 'cookies-and-content-security-policy' ); ?></a>
			</h2>
			<?php if ( $active_tab == 'activate' ) {
				?>
				<div class="cookies-and-content-security-policy-help">
					<?php
					echo '<p>' . __('Activate the plugin to use it.', 'cookies-and-content-security-policy' ) . '</p>';
					?>
				</div>
				<?php
				$cacsp_option_actived = get_cacsp_options( 'cacsp_option_actived' );
				?>
				<table class="form-table">
					<tr>
						<td>
							<fieldset>
								<label for="cacsp_active_false">
									<?php if ( $cacsp_option_actived == 'false' ) {
										$checked = ' checked';
									} else {
										$checked = '';
									} ?>
									<input type="radio" name="cacsp_option_actived" id="cacsp_active_false" value="false"<?php echo $checked; ?>> 
										<strong><?php _e( 'Deactivated', 'cookies-and-content-security-policy' ); ?></strong>
										<small><?php _e( 'Do your settings without disturbing anyone. No modal or Content Security Policy will be used at all.', 'cookies-and-content-security-policy' ); ?></small>
								</label>
								<br>
								<label for="cacsp_active_admin">
									<?php if ( $cacsp_option_actived == 'admin' ) {
										$checked = ' checked';
									} else {
										$checked = '';
									} ?>
									<input type="radio" name="cacsp_option_actived" id="cacsp_active_admin" value="admin"<?php echo $checked; ?>> 
										<strong><?php _e( 'Admin', 'cookies-and-content-security-policy' ); ?></strong>
										<small><?php _e( 'Test your settings without disturbing your visitors. Modal and Content Security Policy will be used only for logged in users with Administrator role.', 'cookies-and-content-security-policy' ); ?></small>
								</label>
								<br>
								<label for="cacsp_active_true">
									<?php if ( $cacsp_option_actived == 'true' || $cacsp_option_actived == null ) {
										$checked = ' checked';
									} else {
										$checked = '';
									} ?>
									<input type="radio" name="cacsp_option_actived" id="cacsp_active_true" value="true"<?php echo $checked; ?>> 
										<strong><?php _e( 'Active', 'cookies-and-content-security-policy' ); ?></strong>
										<small><?php _e( 'We are live!', 'cookies-and-content-security-policy' ); ?></small>
								</label>
								<div class="submit">
									<input type="submit" name="save_cacsp_settings_activate" value="<?php _e( 'Save Settings' , 'cookies-and-content-security-policy' ); ?>" class="button-primary" />
								</div>
							</fieldset>
						</td>
					</tr>
				</table>
			<?php } elseif ( $active_tab == 'domains' ) { 
				?>
				<div class="cookies-and-content-security-policy-help">
					<?php
					echo '<p>';
					_e( 'Fill the forms with domains that should be allowed in each box. The groups are:', 'cookies-and-content-security-policy' );
						echo '<ol>';
							echo '<li>' . __('Always allowed, resources that the visitor can\'t opt out of.', 'cookies-and-content-security-policy' ) . '</li>';
							echo '<li>' . __('Statistics, resources for gathering data about the visitor for statistics etc.', 'cookies-and-content-security-policy' ) . '</li>';
							echo '<li>' . __('Experience, resources for displaying external videos etc.', 'cookies-and-content-security-policy' ) . '</li>';
							echo '<li>' . __('Marketing, resources for gathering data about the visitor for remarketing etc.', 'cookies-and-content-security-policy' ) . '</li>';
						echo '</ol>';
					echo '</p>';
					echo '<p>' . __('Separate domains by new line.<br>Example:<br>https://www.googleadservices.com<br>https://www.googletagmanager.com', 'cookies-and-content-security-policy' ) . '</p>';
					echo '<p>' . __('Wildcard domains can be used.<br>Example:<br>https://*.youtube.com', 'cookies-and-content-security-policy' ) . '</p>';
					?>
				</div>
				<?php
					// Always allowed
					$cacsp_option_always_scripts = get_cacsp_options( 'cacsp_option_always_scripts', false, '', true );
					$cacsp_option_always_images = get_cacsp_options( 'cacsp_option_always_images', false, '', true );
					$cacsp_option_always_frames = get_cacsp_options( 'cacsp_option_always_frames', false, '', true );
					if ( $cacsp_option_forms ) {
						$cacsp_option_always_forms = get_cacsp_options( 'cacsp_option_always_forms', false, '', true );
					}
					// Statistics
					$cacsp_option_statistics_scripts = get_cacsp_options( 'cacsp_option_statistics_scripts', false, '', true );
					$cacsp_option_statistics_images = get_cacsp_options( 'cacsp_option_statistics_images', false, '', true );
					$cacsp_option_statistics_frames = get_cacsp_options( 'cacsp_option_statistics_frames', false, '', true );
					if ( $cacsp_option_forms ) {
						$cacsp_option_statistics_forms = get_cacsp_options( 'cacsp_option_statistics_forms', false, '', true );
					}
					// Experience
					$cacsp_option_experience_scripts = get_cacsp_options( 'cacsp_option_experience_scripts', false, '', true );
					$cacsp_option_experience_images = get_cacsp_options( 'cacsp_option_experience_images', false, '', true );
					$cacsp_option_experience_frames = get_cacsp_options( 'cacsp_option_experience_frames', false, '', true );
					if ( $cacsp_option_forms ) {
						$cacsp_option_experience_forms = get_cacsp_options( 'cacsp_option_experience_forms', false, '', true );
					}
					// Marketing
					$cacsp_option_markerting_scripts = get_cacsp_options( 'cacsp_option_markerting_scripts', false, '', true );
					$cacsp_option_markerting_images = get_cacsp_options( 'cacsp_option_markerting_images', false, '', true );
					$cacsp_option_markerting_frames = get_cacsp_options( 'cacsp_option_markerting_frames', false, '', true );
					if ( $cacsp_option_forms ) {
						$cacsp_option_markerting_forms = get_cacsp_options( 'cacsp_option_markerting_forms', false, '', true );
					}
					?>
				<h2><?php _e( 'Always allow', 'cookies-and-content-security-policy' ); ?></h2>
				<table class="form-table">
					<?php echo cacsp_settings_textarea_row( __('Scripts', 'cookies-and-content-security-policy' ), 'cacsp_option_always_scripts', $cacsp_option_always_scripts, true, __('Your CDN, like https://media.yourdomain.com/', 'cookies-and-content-security-policy' ) ); ?>
					<?php echo cacsp_settings_textarea_row( __('Images', 'cookies-and-content-security-policy' ), 'cacsp_option_always_images', $cacsp_option_always_images, true, __('Your CDN, like https://media.yourdomain.com/', 'cookies-and-content-security-policy' ) ); ?>
					<?php echo cacsp_settings_textarea_row( __('Frames', 'cookies-and-content-security-policy' ), 'cacsp_option_always_frames', $cacsp_option_always_frames, true, __('Your CDN, like https://media.yourdomain.com/', 'cookies-and-content-security-policy' ) ); ?>
					<?php if ( $cacsp_option_forms ) {
						echo cacsp_settings_textarea_row( __('Forms', 'cookies-and-content-security-policy' ), 'cacsp_option_always_forms', $cacsp_option_always_forms, true, __('Use this to allow posting data to other sites, like subscribing to a MailChimp newsletter would need https://*.list-manage.com/', 'cookies-and-content-security-policy' ) );
					} ?>
				</table>
				<h2><?php _e( 'Statistics', 'cookies-and-content-security-policy' ); ?></h2>
				<table class="form-table">
					<?php echo cacsp_settings_textarea_row( __('Scripts', 'cookies-and-content-security-policy' ), 'cacsp_option_statistics_scripts', $cacsp_option_statistics_scripts, true, 'https://www.google-analytics.com/' ); ?>
					<?php echo cacsp_settings_textarea_row( __('Images', 'cookies-and-content-security-policy' ), 'cacsp_option_statistics_images', $cacsp_option_statistics_images, true, 'https://www.google-analytics.com/' ); ?>
					<?php echo cacsp_settings_textarea_row( __('Frames', 'cookies-and-content-security-policy' ), 'cacsp_option_statistics_frames', $cacsp_option_statistics_frames, true, __('No idea :)', 'cookies-and-content-security-policy' ) ); ?>
					<?php if ( $cacsp_option_forms ) {
						echo cacsp_settings_textarea_row( __('Forms', 'cookies-and-content-security-policy' ), 'cacsp_option_statistics_forms', $cacsp_option_statistics_forms, true, __('Use this to allow posting data to other sites, like subscribing to a MailChimp newsletter would need https://*.list-manage.com/', 'cookies-and-content-security-policy' ) ); 
					} ?>
				</table>
				<h2><?php _e( 'Experience', 'cookies-and-content-security-policy' ); ?></h2>
				<table class="form-table">
					<?php echo cacsp_settings_textarea_row( __('Scripts', 'cookies-and-content-security-policy' ), 'cacsp_option_experience_scripts', $cacsp_option_experience_scripts, true, 'https://ajax.googleapis.com/' ); ?>
					<?php echo cacsp_settings_textarea_row( __('Images', 'cookies-and-content-security-policy' ), 'cacsp_option_experience_images', $cacsp_option_experience_images, true, 'https://secure.gravatar.com/' ); ?>
					<?php echo cacsp_settings_textarea_row( __('Frames', 'cookies-and-content-security-policy' ), 'cacsp_option_experience_frames', $cacsp_option_experience_frames, true, 'https://*.youtube.com/<br>https://*.vimeo.com/<br>https://www.google.com/' ); ?>
					<?php if ( $cacsp_option_forms ) {
						echo cacsp_settings_textarea_row( __('Forms', 'cookies-and-content-security-policy' ), 'cacsp_option_experience_forms', $cacsp_option_experience_forms, true, __('Use this to allow posting data to other sites, like subscribing to a MailChimp newsletter would need https://*.list-manage.com/', 'cookies-and-content-security-policy' ) );
					} ?>
				</table>
				<h2><?php _e( 'Marketing', 'cookies-and-content-security-policy' ); ?></h2>
				<table class="form-table">
					<?php echo cacsp_settings_textarea_row( __('Scripts', 'cookies-and-content-security-policy' ), 'cacsp_option_markerting_scripts', $cacsp_option_markerting_scripts, true, 'https://*.facebook.net/<br>https://tagmanager.google.com/<br>https://www.googletagmanager.com/<br>https://www.googleadservices.com/' ); ?>
					<?php echo cacsp_settings_textarea_row( __('Images', 'cookies-and-content-security-policy' ), 'cacsp_option_markerting_images', $cacsp_option_markerting_images, true, 'https://*.facebook.net/<br>https://*.facebook.com/<br>https://*.google.com/<br>https://*.google.se/<br>https://*.linkedin.com/' ); ?>
					<?php echo cacsp_settings_textarea_row( __('Frames', 'cookies-and-content-security-policy' ), 'cacsp_option_markerting_frames', $cacsp_option_markerting_frames, true, __('No idea :)', 'cookies-and-content-security-policy' ) ); ?>
					<?php if ( $cacsp_option_forms ) {
						echo cacsp_settings_textarea_row( __('Forms', 'cookies-and-content-security-policy' ), 'cacsp_option_markerting_forms', $cacsp_option_markerting_forms, true, __('Use this to allow posting data to other sites, like subscribing to a MailChimp newsletter would need https://*.list-manage.com/', 'cookies-and-content-security-policy' ) );
					} ?>
				</table>

				<div class="submit">
					<input type="submit" name="save_cacsp_settings_domains" value="<?php _e( 'Save Settings' , 'cookies-and-content-security-policy' ); ?>" class="button-primary" />
				</div>
			<?php } elseif ( $active_tab == 'texts' ) { ?>
				<div class="cookies-and-content-security-policy-help">
					<?php
					echo '<p>';
						_e( 'You don\'t have to fill out this form, the plugin comes with all the texts you need. But if you want other texts than that, enter them here.', 'cookies-and-content-security-policy' );
					echo '</p>';
					?>
				</div>
				<?php
				$cacsp_option_text_header = get_cacsp_options( 'cacsp_option_text_header', false, '', true );
				$cacsp_option_text_info = get_cacsp_options( 'cacsp_option_text_info', false, '', true );
				$cacsp_option_text_link_text = get_cacsp_options( 'cacsp_option_text_link_text', false, '', true );
				$cacsp_option_text_settings = get_cacsp_options( 'cacsp_option_text_settings', false, '', true );
				$cacsp_option_text_always_allow_header = get_cacsp_options( 'cacsp_option_text_always_allow_header', false, '', true );
				$cacsp_option_text_always_allow_description = get_cacsp_options( 'cacsp_option_text_always_allow_description', false, '', true );
				$cacsp_option_text_statistics_header = get_cacsp_options( 'cacsp_option_text_statistics_header', false, '', true );
				$cacsp_option_text_statistics_description = get_cacsp_options( 'cacsp_option_text_statistics_description', false, '', true );
				$cacsp_option_text_experience_header = get_cacsp_options( 'cacsp_option_text_experience_header', false, '', true );
				$cacsp_option_text_experience_description = get_cacsp_options( 'cacsp_option_text_experience_description', false, '', true );
				$cacsp_option_text_marketing_header = get_cacsp_options( 'cacsp_option_text_marketing_header', false, '', true );
				$cacsp_option_text_marketing_description = get_cacsp_options( 'cacsp_option_text_marketing_description', false, '', true );
				$cacsp_option_settings_button = get_cacsp_options( 'cacsp_option_settings_button', false, '', true );
				$cacsp_option_accept_all_button = get_cacsp_options( 'cacsp_option_accept_all_button', false, '', true );
				$cacsp_option_save_button = get_cacsp_options( 'cacsp_option_save_button', false, '', true );
				$cacsp_review_settings_description = get_cacsp_options( 'cacsp_review_settings_description', false, '', true );
				$cacsp_review_settings_button = get_cacsp_options( 'cacsp_review_settings_button', false, '', true );
				$cacsp_not_allowed_description = get_cacsp_options( 'cacsp_not_allowed_description', false, '', true );
				$cacsp_not_allowed_button = get_cacsp_options( 'cacsp_not_allowed_button', false, '', true );
				?>
				<h2><?php _e( 'Texts', 'cookies-and-content-security-policy' ); ?></h2>
				<table class="form-table">
					<?php echo cacsp_settings_input_row( __('Modal header', 'cookies-and-content-security-policy', false ), 'cacsp_option_text_header', $cacsp_option_text_header, false, '', __( 'Cookies', 'cookies-and-content-security-policy' ) ); ?>
					<?php echo cacsp_settings_textarea_row( __('Info', 'cookies-and-content-security-policy', false ), 'cacsp_option_text_info', $cacsp_option_text_info, false, '', __( 'We serve cookies. If you think that\'s ok, just click "Accept all". You can also choose what kind of cookies you want by clicking "Settings".', 'cookies-and-content-security-policy' ) ); ?>
					<?php echo cacsp_settings_input_row( __('Cookie policy link text', 'cookies-and-content-security-policy', false ), 'cacsp_option_text_link_text', $cacsp_option_text_link_text, false, '', __( 'Read our cookie policy', 'cookies-and-content-security-policy' ) ); ?>
					<?php echo cacsp_settings_textarea_row( __('Settings text', 'cookies-and-content-security-policy', false ), 'cacsp_option_text_settings', $cacsp_option_text_settings, false, '', __( 'Choose what kind of cookies to accept.', 'cookies-and-content-security-policy' ) ); ?>
					<?php echo cacsp_settings_input_row( __('Always allow, header', 'cookies-and-content-security-policy', false ), 'cacsp_option_text_always_allow_header', $cacsp_option_text_always_allow_header, false, '', __( 'Necessary', 'cookies-and-content-security-policy' ) ); ?>
					<?php echo cacsp_settings_textarea_row( __('Always allow, description', 'cookies-and-content-security-policy', false ), 'cacsp_option_text_always_allow_description', $cacsp_option_text_always_allow_description, false, '', __( 'These cookies are not optional. They are needed for the website to function.', 'cookies-and-content-security-policy' ) ); ?>
					<?php echo cacsp_settings_input_row( __('Statistics, header', 'cookies-and-content-security-policy', false ), 'cacsp_option_text_statistics_header', $cacsp_option_text_statistics_header, false, '', __( 'Statistics', 'cookies-and-content-security-policy' ) ); ?>
					<?php echo cacsp_settings_textarea_row( __('Statistics, description', 'cookies-and-content-security-policy', false ), 'cacsp_option_text_statistics_description', $cacsp_option_text_statistics_description, false, '', __( 'In order for us to improve the website\'s functionality and structure, based on how the website is used.', 'cookies-and-content-security-policy' ) ); ?>
					<?php echo cacsp_settings_input_row( __('Experience, header', 'cookies-and-content-security-policy', false ), 'cacsp_option_text_experience_header', $cacsp_option_text_experience_header, false, '', __( 'Experience', 'cookies-and-content-security-policy' ) ); ?>
					<?php echo cacsp_settings_textarea_row( __('Experience, description', 'cookies-and-content-security-policy', false ), 'cacsp_option_text_experience_description', $cacsp_option_text_experience_description, false, '', __( 'In order for our website to perform as well as possible during your visit. If you refuse these cookies, some functionality will disappear from the website.', 'cookies-and-content-security-policy' ) ); ?>
					<?php echo cacsp_settings_input_row( __('Marketing, header', 'cookies-and-content-security-policy', false ), 'cacsp_option_text_marketing_header', $cacsp_option_text_marketing_header, false, '', __( 'Marketing', 'cookies-and-content-security-policy' ) ); ?>
					<?php echo cacsp_settings_textarea_row( __('Marketing, description', 'cookies-and-content-security-policy', false ), 'cacsp_option_text_marketing_description', $cacsp_option_text_marketing_description, false, '', __( 'By sharing your interests and behavior as you visit our site, you increase the chance of seeing personalized content and offers.', 'cookies-and-content-security-policy' ) ); ?>
					<?php echo cacsp_settings_input_row( __('Settings button', 'cookies-and-content-security-policy', false ), 'cacsp_option_settings_button', $cacsp_option_settings_button, false, '', __( 'Settings', 'cookies-and-content-security-policy' ) ); ?>
					<?php echo cacsp_settings_input_row( __('Accept all button', 'cookies-and-content-security-policy', false ), 'cacsp_option_accept_all_button', $cacsp_option_accept_all_button, false, '', __( 'Accept all', 'cookies-and-content-security-policy' ) ); ?>
					<?php echo cacsp_settings_input_row( __('Save button', 'cookies-and-content-security-policy', false ), 'cacsp_option_save_button', $cacsp_option_save_button, false, '', __( 'Save', 'cookies-and-content-security-policy' ) ); ?>
					<?php echo cacsp_settings_textarea_row( __('Review your settings text', 'cookies-and-content-security-policy', false ), 'cacsp_review_settings_description', $cacsp_review_settings_description, false, '', __( 'Your settings may be preventing you from seeing this content. Most likely you have Experience turned off.', 'cookies-and-content-security-policy' ) ); ?>
					<?php echo cacsp_settings_input_row( __('Review your settings button', 'cookies-and-content-security-policy', false ), 'cacsp_review_settings_button', $cacsp_review_settings_button, false, '', __( 'Review your settings', 'cookies-and-content-security-policy' ) ); ?>
					<?php echo cacsp_settings_textarea_row( __('Content not allowed text', 'cookies-and-content-security-policy', false ), 'cacsp_not_allowed_description', $cacsp_not_allowed_description, false, '', __( 'The content can\'t be loaded, since it is not allowed on the site.', 'cookies-and-content-security-policy' ) ); ?>
					<?php echo cacsp_settings_input_row( __('Content not allowed button', 'cookies-and-content-security-policy', false ), 'cacsp_not_allowed_button', $cacsp_not_allowed_button, false, '', __( 'Contact the administrator', 'cookies-and-content-security-policy' ) ); ?>
				</table>

				<div class="submit">
					<input type="submit" name="save_cacsp_settings_texts" value="<?php _e( 'Save Settings' , 'cookies-and-content-security-policy' ); ?>" class="button-primary" />
				</div>
			<?php } elseif ( $active_tab == 'settings' ) { ?>
				<div class="cookies-and-content-security-policy-help">
					<?php
					echo '<p>';
						_e( 'You don\'t have to fill out this form, the plugin comes with default settings. But if you want to change settings, this is it.', 'cookies-and-content-security-policy' );
					echo '</p>';
					?>
				</div>
				<?php
				$cacsp_option_only_csp = get_cacsp_options( 'cacsp_option_only_csp', false, '', true );
				$cacsp_option_own_style = get_cacsp_options( 'cacsp_option_own_style', false, '', true );
				$cacsp_option_own_js = get_cacsp_options( 'cacsp_option_own_js', false, '', true );
				$cacsp_option_banner = get_cacsp_options( 'cacsp_option_banner', false, '', true );
				$cacsp_option_allow_use_site = get_cacsp_options( 'cacsp_option_allow_use_site', false, '', true );
				$cacsp_option_forms = get_cacsp_options( 'cacsp_option_forms', false, '', true );
				$cacsp_option_meta = get_cacsp_options( 'cacsp_option_meta', false, '', true );
				$cacsp_option_debug = get_cacsp_options( 'cacsp_option_debug', false, '', true );
				$cacsp_option_settings_policy_link = get_cacsp_options( 'cacsp_option_settings_policy_link', false, '', true );
				?>
				<h2><?php _e( 'Settings', 'cookies-and-content-security-policy' ); ?></h2>
				<table class="form-table">
					<tr>
						<th scope="row">
							<?php _e( 'Basic settings', 'cookies-and-content-security-policy' ); ?>
						</th>
						<td>
							<fieldset>
								<label for="cacsp_option_only_csp">
									<?php if ( $cacsp_option_only_csp ) {
										$checked = ' checked';
									} else {
										$checked = '';
									} ?>
									<input type="checkbox" name="cacsp_option_only_csp" id="cacsp_option_only_csp" value="1"<?php echo $checked; ?>> 
										<?php _e( 'Only use CSP, no modal for me. This will only make use of domains in Always allowed.', 'cookies-and-content-security-policy' ); ?>
								</label>
								<br>
								<label for="cacsp_option_banner">
									<?php if ( $cacsp_option_banner ) {
										$checked = ' checked';
									} else {
										$checked = '';
									} ?>
									<input type="checkbox" name="cacsp_option_banner" id="cacsp_option_banner" value="1"<?php echo $checked; ?>> 
										<?php _e( 'Do not use a modal, I want a banner.', 'cookies-and-content-security-policy' ); ?>
								</label>
								<br>
								<label for="cacsp_option_allow_use_site">
									<?php if ( $cacsp_option_allow_use_site ) {
										$checked = ' checked';
									} else {
										$checked = '';
									} ?>
									<input type="checkbox" name="cacsp_option_allow_use_site" id="cacsp_option_allow_use_site" value="1"<?php echo $checked; ?>> 
										<?php _e( 'Allow user to access site without saving settings. Only works with banner.', 'cookies-and-content-security-policy' ); ?>
								</label>
							</fieldset>
						</td>
					</tr>
					<tr>
						<th scope="row">
							<?php _e( 'Advanced settings', 'cookies-and-content-security-policy' ); ?>
						</th>
						<td>
							<fieldset>
								<label for="cacsp_option_own_style">
									<?php if ( $cacsp_option_own_style ) {
										$checked = ' checked';
									} else {
										$checked = '';
									} ?>
									<input type="checkbox" name="cacsp_option_own_style" id="cacsp_option_own_style" value="1"<?php echo $checked; ?>> 
										<?php _e( 'Do not include css, I\'ve got my own style.', 'cookies-and-content-security-policy' ); ?>
								</label>
								<br>
								<label for="cacsp_option_own_js">
									<?php if ( $cacsp_option_own_js ) {
										$checked = ' checked';
									} else {
										$checked = '';
									} ?>
									<input type="checkbox" name="cacsp_option_own_js" id="cacsp_option_own_js" value="1"<?php echo $checked; ?>> 
										<?php _e( 'Do not include js, I\'ve got my own script.', 'cookies-and-content-security-policy' ); ?>
								</label>
								<br>
								<label for="cacsp_option_forms">
									<?php if ( $cacsp_option_forms ) {
										$checked = ' checked';
									} else {
										$checked = '';
									} ?>
									<input type="checkbox" name="cacsp_option_forms" id="cacsp_option_forms" value="1"<?php echo $checked; ?>> 
										<?php _e( 'Use Content Security Policy for forms for added security. (recommended)', 'cookies-and-content-security-policy' ); ?>
								</label>
								<br>
								<label for="cacsp_option_meta">
									<?php if ( $cacsp_option_meta ) {
										$checked = ' checked';
									} else {
										$checked = '';
									} ?>
									<input type="checkbox" name="cacsp_option_meta" id="cacsp_option_meta" value="1"<?php echo $checked; ?>> 
										<?php _e( 'Use meta. If your host does not accept setting php header(), check this to add CSP as a meta tag in the header instead.', 'cookies-and-content-security-policy' ); ?>
								</label>
								<br>
								<label for="cacsp_option_debug">
									<?php if ( $cacsp_option_debug ) {
										$checked = ' checked';
									} else {
										$checked = '';
									} ?>
									<input type="checkbox" name="cacsp_option_debug" id="cacsp_option_debug" value="1"<?php echo $checked; ?>> 
										<?php _e( 'Debug. This will print helpful comments at the beginning of your page.', 'cookies-and-content-security-policy' ); ?>
								</label>
							</fieldset>
						</td>
					</tr>
					<tr>
						<th scope="row">
							<?php _e( 'Cookie policy page', 'cookies-and-content-security-policy' ); ?>
						</th>
						<td>
							<?php
							echo wp_dropdown_pages(
									array(
										'name'              => 'cacsp_option_settings_policy_link',
										'echo'              => 0,
										'show_option_none'  => __( '&mdash; Select &mdash;' ),
										'option_none_value' => '0',
										'selected'          => $cacsp_option_settings_policy_link,
									)
								)
							?>
							<small><?php _e( 'Will be linked from the cookie modal. Does not show the the cookie modal for the user to be able to read the polcy befor accepting.', 'cookies-and-content-security-policy' ); ?></small>
						</td>
					</tr>
					<tr>
						<th scope="row">
							<?php _e( 'How to link back to settings', 'cookies-and-content-security-policy' ); ?>
						</th>
						<td>
							<?php _e( 'If you want to link back to the settings modal simply add a link with href = "#cookiesAndContentPolicySettings"', 'cookies-and-content-security-policy' ); ?>
						</td>
					</tr>
				</table>

				<div class="submit">
					<input type="submit" name="save_cacsp_settings_settings" value="<?php _e( 'Save Settings' , 'cookies-and-content-security-policy' ); ?>" class="button-primary" />
				</div>
			<?php } elseif ( $active_tab == 'colors' ) { ?>
				<div class="cookies-and-content-security-policy-help">
					<?php
					echo '<p>';
						_e( 'You don\'t have to fill out this form, the plugin comes with default colors. But if you want to change the colors, this is it.', 'cookies-and-content-security-policy' );
					echo '</p>';
					?>
				</div>
				<?php
				$cacsp_option_color_backdrop = get_cacsp_options( 'cacsp_option_color_backdrop', false, '', true );
				$cacsp_option_color_modal_bg = get_cacsp_options( 'cacsp_option_color_modal_bg', false, '', true );
				$cacsp_option_color_modal_header_bg = get_cacsp_options( 'cacsp_option_color_modal_header_bg', false, '', true );
				$cacsp_option_color_modal_list_border = get_cacsp_options( 'cacsp_option_color_modal_list_border', false, '', true );
				$cacsp_option_color_modal_text_color = get_cacsp_options( 'cacsp_option_color_modal_text_color', false, '', true );
				$cacsp_option_color_modal_header_text_color = get_cacsp_options( 'cacsp_option_color_modal_header_text_color', false, '', true );
				$cacsp_option_color_text_on = get_cacsp_options( 'cacsp_option_color_text_on', false, '', true );
				$cacsp_option_color_off = get_cacsp_options( 'cacsp_option_color_off', false, '', true );
				$cacsp_option_color_on = get_cacsp_options( 'cacsp_option_color_on', false, '', true );
				$cacsp_option_color_settings_button = get_cacsp_options( 'cacsp_option_color_settings_button', false, '', true );
				$cacsp_option_color_settings_button_border = get_cacsp_options( 'cacsp_option_color_settings_button_border', false, '', true );
				$cacsp_option_color_settings_button_text = get_cacsp_options( 'cacsp_option_color_settings_button_text', false, '', true );
				$cacsp_option_color_save_button = get_cacsp_options( 'cacsp_option_color_save_button', false, '', true );
				$cacsp_option_color_save_button_border = get_cacsp_options( 'cacsp_option_color_save_button_border', false, '', true );
				$cacsp_option_color_save_button_text = get_cacsp_options( 'cacsp_option_color_save_button_text', false, '', true );
				$cacsp_option_color_accept_button = get_cacsp_options( 'cacsp_option_color_accept_button', false, '', true );
				$cacsp_option_color_accept_button_border = get_cacsp_options( 'cacsp_option_color_accept_button_border', false, '', true );
				$cacsp_option_color_accept_button_text = get_cacsp_options( 'cacsp_option_color_accept_button_text', false, '', true );
				?>
				<h2><?php _e( 'Colors', 'cookies-and-content-security-policy' ); ?></h2>
				<p><?php _e( 'Use the default colors or pick you own here.', 'cookies-and-content-security-policy' ); ?></p>
				<h3><?php _e( 'Backgrounds', 'cookies-and-content-security-policy' ); ?></h3>
				<table class="form-table">
					<tr>
						<th scope="row">
							<?php _e( 'Backdrop', 'cookies-and-content-security-policy' ); ?>
						</th>
						<td>
							<input name="cacsp_option_color_backdrop" type="text" id="cacsp_option_color_backdrop" value="<?php echo $cacsp_option_color_backdrop; ?>" class="cacsp-color">
						</td>
					</tr>
					<tr>
						<th scope="row">
							<?php _e( 'Modal background', 'cookies-and-content-security-policy' ); ?>
						</th>
						<td>
							<input name="cacsp_option_color_modal_bg" type="text" id="cacsp_option_color_modal_bg" value="<?php echo $cacsp_option_color_modal_bg; ?>" class="cacsp-color">
						</td>
					</tr>
					<tr>
						<th scope="row">
							<?php _e( 'Modal header background', 'cookies-and-content-security-policy' ); ?>
						</th>
						<td>
							<input name="cacsp_option_color_modal_header_bg" type="text" id="cacsp_option_color_modal_header_bg" value="<?php echo $cacsp_option_color_modal_header_bg; ?>" class="cacsp-color">
						</td>
					</tr>
					<tr>
						<th scope="row">
							<?php _e( 'Modal list border', 'cookies-and-content-security-policy' ); ?>
						</th>
						<td>
							<input name="cacsp_option_color_modal_list_border" type="text" id="cacsp_option_color_modal_list_border" value="<?php echo $cacsp_option_color_modal_list_border; ?>" class="cacsp-color">
						</td>
					</tr>
				</table>
				<h3><?php _e( 'Texts', 'cookies-and-content-security-policy' ); ?></h3>
				<table class="form-table">
					<tr>
						<th scope="row">
							<?php _e( 'Modal text color', 'cookies-and-content-security-policy' ); ?>
						</th>
						<td>
							<input name="cacsp_option_color_modal_text_color" type="text" id="cacsp_option_color_modal_text_color" value="<?php echo $cacsp_option_color_modal_text_color; ?>" class="cacsp-color">
						</td>
					</tr>
					<tr>
						<th scope="row">
							<?php _e( 'Modal text header color', 'cookies-and-content-security-policy' ); ?>
						</th>
						<td>
							<input name="cacsp_option_color_modal_header_text_color" type="text" id="cacsp_option_color_modal_header_text_color" value="<?php echo $cacsp_option_color_modal_header_text_color; ?>" class="cacsp-color">
						</td>
					</tr>
					<tr>
						<th scope="row">
							<?php _e( 'On switch, text color', 'cookies-and-content-security-policy' ); ?>
						</th>
						<td>
							<input name="cacsp_option_color_text_on" type="text" id="cacsp_option_color_text_on" value="<?php echo $cacsp_option_color_text_on; ?>" class="cacsp-color">
						</td>
					</tr>
				</table>
				<h3><?php _e( 'Buttons', 'cookies-and-content-security-policy' ); ?></h3>
				<table class="form-table">
					<tr>
						<th scope="row">
							<?php _e( 'Off switch', 'cookies-and-content-security-policy' ); ?>
						</th>
						<td>
							<input name="cacsp_option_color_off" type="text" id="cacsp_option_color_off" value="<?php echo $cacsp_option_color_off; ?>" class="cacsp-color">
						</td>
					</tr>
					<tr>
						<th scope="row">
							<?php _e( 'On switch', 'cookies-and-content-security-policy' ); ?>
						</th>
						<td>
							<input name="cacsp_option_color_on" type="text" id="cacsp_option_color_on" value="<?php echo $cacsp_option_color_on; ?>" class="cacsp-color">
						</td>
					</tr>
					<tr>
						<th scope="row">
							<?php _e( 'Settings button color', 'cookies-and-content-security-policy' ); ?>
						</th>
						<td>
							<input name="cacsp_option_color_settings_button" type="text" id="cacsp_option_color_settings_button" value="<?php echo $cacsp_option_color_settings_button; ?>" class="cacsp-color">
						</td>
					</tr>
					<tr>
						<th scope="row">
							<?php _e( 'Settings button border', 'cookies-and-content-security-policy' ); ?>
						</th>
						<td>
							<input name="cacsp_option_color_settings_button_border" type="text" id="cacsp_option_color_settings_button_border" value="<?php echo $cacsp_option_color_settings_button_border; ?>" class="cacsp-color">
						</td>
					</tr>
					<tr>
						<th scope="row">
							<?php _e( 'Settings button text', 'cookies-and-content-security-policy' ); ?>
						</th>
						<td>
							<input name="cacsp_option_color_settings_button_text" type="text" id="cacsp_option_color_settings_button_text" value="<?php echo $cacsp_option_color_settings_button_text; ?>" class="cacsp-color">
						</td>
					</tr>
					<tr>
						<th scope="row">
							<?php _e( 'Save button color', 'cookies-and-content-security-policy' ); ?>
						</th>
						<td>
							<input name="cacsp_option_color_save_button" type="text" id="cacsp_option_color_save_button" value="<?php echo $cacsp_option_color_save_button; ?>" class="cacsp-color">
						</td>
					</tr>
					<tr>
						<th scope="row">
							<?php _e( 'Save button border', 'cookies-and-content-security-policy' ); ?>
						</th>
						<td>
							<input name="cacsp_option_color_save_button_border" type="text" id="cacsp_option_color_save_button_border" value="<?php echo $cacsp_option_color_save_button_border; ?>" class="cacsp-color">
						</td>
					</tr>
					<tr>
						<th scope="row">
							<?php _e( 'Save button text', 'cookies-and-content-security-policy' ); ?>
						</th>
						<td>
							<input name="cacsp_option_color_save_button_text" type="text" id="cacsp_option_color_save_button_text" value="<?php echo $cacsp_option_color_save_button_text; ?>" class="cacsp-color">
						</td>
					</tr>
					<tr>
						<th scope="row">
							<?php _e( 'Accept button color', 'cookies-and-content-security-policy' ); ?>
						</th>
						<td>
							<input name="cacsp_option_color_accept_button" type="text" id="cacsp_option_color_accept_button" value="<?php echo $cacsp_option_color_accept_button; ?>" class="cacsp-color">
						</td>
					</tr>
					<tr>
						<th scope="row">
							<?php _e( 'Accept button border', 'cookies-and-content-security-policy' ); ?>
						</th>
						<td>
							<input name="cacsp_option_color_accept_button_border" type="text" id="cacsp_option_color_accept_button_border" value="<?php echo $cacsp_option_color_accept_button_border; ?>" class="cacsp-color">
						</td>
					</tr>
					<tr>
						<th scope="row">
							<?php _e( 'Accept button text', 'cookies-and-content-security-policy' ); ?>
						</th>
						<td>
							<input name="cacsp_option_color_accept_button_text" type="text" id="cacsp_option_color_accept_button_text" value="<?php echo $cacsp_option_color_accept_button_text; ?>" class="cacsp-color">
						</td>
					</tr>
				</table>
				
				<div class="submit">
					<input type="submit" name="save_cacsp_settings_colors" value="<?php _e( 'Save Settings' , 'cookies-and-content-security-policy' ); ?>" class="button-primary" />
				</div>
			<?php } elseif ( $active_tab == 'support' ) { ?>
				<div class="wrap">
					<h2><?php _e( 'Support', 'cookies-and-content-security-policy' ); ?></h2>
					<h3><?php _e( 'Want support?', 'cookies-and-content-security-policy' ); ?></h3>
					<p><a href="https://wordpress.org/support/plugin/cookies-and-content-security-policy/" target="_blank" rel="noopener noreferrer"><?php _e( 'Visit the support forum for the plugin at WordPress.org.', 'cookies-and-content-security-policy' ); ?></a></p>
					<h3><?php _e( 'Want to support the plugin?', 'cookies-and-content-security-policy' ); ?></h3>
					<p><?php _e( 'Yes, the plugin is free. Totally free. But if you still want to pay for it to show your appreciation:', 'cookies-and-content-security-policy' ); ?> <a href="https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=2MFCSWP6VAUCG&source=url" target="_blank" rel="noopener noreferrer"><?php _e( 'Donate with PayPal', 'cookies-and-content-security-policy' ); ?></a>. <?php _e( 'It would make my day. :)', 'cookies-and-content-security-policy' ); ?></p>
				</div>
			<?php }
			wp_nonce_field( 'cacsp_nonce_action', 'cacsp_nonce_name', false );
			?>
		</form>
	</div>
	<script>
	jQuery(function() {
		var cookiesAndContentPolicyForm = jQuery('.settings_page_cacsp_settings form');
		var initialState = cookiesAndContentPolicyForm.serialize();
		jQuery('.settings_page_cacsp_settings a.nav-tab ').click(function (e) {
			if (initialState !== cookiesAndContentPolicyForm.serialize()) {
				window.onbeforeunload = function() {
				   return '<?php _e( 'You have unsaved changes, do you want to continue?', 'cookies-and-content-security-policy' ); ?>';
				};
			}
		});
	});
	jQuery(function() {
	    jQuery('.cacsp-color').wpColorPicker();
	});
	</script>
<?php
}
